Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: net/proxy/proxy_config.h

Issue 149191: Whenever proxy configurations contain socks and http/https/ftp proxies, socks... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/proxy/proxy_config.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_config.h
===================================================================
--- net/proxy/proxy_config.h (revision 20472)
+++ net/proxy/proxy_config.h (working copy)
@@ -68,17 +68,20 @@
// URLs.
void ParseFromString(const std::string& proxy_rules);
- // Returns one of {&proxy_for_http, &proxy_for_https, &proxy_for_ftp},
- // or NULL if it is a scheme that we don't have a mapping for. Should only
- // call this if the type is TYPE_PROXY_PER_SCHEME.
- const ProxyServer* MapSchemeToProxy(const std::string& scheme) const;
+ // Returns one of {&proxy_for_http, &proxy_for_https, &proxy_for_ftp,
+ // &socks_proxy}, or NULL if it is a scheme that we don't have a mapping
+ // for. If the scheme mapping is not present and socks_proxy is defined,
+ // we fall back to using socks_proxy.
+ // Should only call this if the type is TYPE_PROXY_PER_SCHEME.
+ const ProxyServer* MapUrlSchemeToProxy(const std::string& url_scheme) const;
bool operator==(const ProxyRules& other) const {
return type == other.type &&
single_proxy == other.single_proxy &&
proxy_for_http == other.proxy_for_http &&
proxy_for_https == other.proxy_for_https &&
- proxy_for_ftp == other.proxy_for_ftp;
+ proxy_for_ftp == other.proxy_for_ftp &&
+ socks_proxy == other.socks_proxy;
}
Type type;
@@ -90,6 +93,14 @@
ProxyServer proxy_for_http;
ProxyServer proxy_for_https;
ProxyServer proxy_for_ftp;
+
+ // Set if configuration has SOCKS proxy.
+ ProxyServer socks_proxy;
+ private:
+ // Returns one of {&proxy_for_http, &proxy_for_https, &proxy_for_ftp,
+ // &socks_proxy}, or NULL if it is a scheme that we don't have a mapping
+ // for. Should only call this if the type is TYPE_PROXY_PER_SCHEME.
+ ProxyServer* MapSchemeToProxy(const std::string& scheme);
};
ProxyRules proxy_rules;
« no previous file with comments | « no previous file | net/proxy/proxy_config.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698